@@ -1,15 +1,10 @@
-"""Top-level package for camera_match."""
-
-__author__ = """Ethan Ou"""
-__email__ = 'ethantim@gmail.com'
-__version__ = '0.0.2'
-
 from .nodes import (
     Lift,
     Gain,
     CurvesInterpolation,
     CurvesEMOR,
-    RBF,
+    LUT3D,
+    LUT2D,
     LUT,
     LinearMatrix,
     RootPolynomialMatrix,
@@ -18,6 +13,4 @@ from .nodes import (
     CST,
 )
 
-from .pipeline import (
-    Pipeline
-)
+from .pipeline import Pipeline
